==> flutter_boost_assassin-0.0.1.tar.gz: lib/messaging/message_proxy.dart <==
/*
 * The MIT License (MIT)
 * 
 * Copyright (c) 2019 Alibaba Group
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
import 'package:flutter_boost_assassin/AIOService/NavigationService/service/NavigationService.dart';
import 'dart:async';

abstract class MessageProxy{
  Future<bool> openPage(String pageName,Map params,bool animated);
  Future<bool> closePage(String uniqueId,String pageName,Map params,bool animated);
}

class MessageProxyImp implements MessageProxy{
  @override
  Future<bool> openPage(String pageName, Map params, bool animated) {
    return NavigationService.openPage(pageName, params, animated);
  }

  @override
  Future<bool> closePage(String uniqueId, String pageName, Map params, bool animated) {
    return NavigationService.closePage(uniqueId, pageName, params, animated);
  }
}

==> flutter_boost_assassin-0.0.5.tar.gz: lib/messaging/message_proxy.dart <==
/*
 * The MIT License (MIT)
 * 
 * Copyright (c) 2019 Alibaba Group
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
import 'package:flutter_boost_assassin/AIOService/NavigationService/service/navigation_service.dart';
import 'dart:async';

abstract class MessageProxy{
  Future<bool> openPage(String pageName,Map params,bool animated);
  Future<bool> closePage(String uniqueId,String pageName,Map params,bool animated);
}

class MessageProxyImp implements MessageProxy{
  @override
  Future<bool> openPage(String pageName, Map params, bool animated) {
    return NavigationService.openPage(pageName, params, animated);
  }

  @override
  Future<bool> closePage(String uniqueId, String pageName, Map params, bool animated) {
    return NavigationService.closePage(uniqueId, pageName, params, animated);
  }
}
